@@ -45,11 +45,22 @@ BarWidget::BarWidget(int dueWords[], int totalDueWords, int percentageCompleted,
     QPalette palette(BarWidget::palette());
     palette.setColor(backgroundRole(), Qt::white);
     setPalette(palette);
-    for (int i = 0; i < 8; i++) {
-        this->dueWords[i] = dueWords[i];
+    for (int i = 0; i <= KV_MAX_GRADE; i++) {
+        m_dueWords[i] = dueWords[i];
     }
-    this->totalDueWords = totalDueWords;
-    this->percentageCompleted = percentageCompleted;
+    m_totalDueWords = totalDueWords;
+    m_percentageCompleted = percentageCompleted;
+}
+
+
+void BarWidget::setDue(WordCount &wc)
+{
+    for (int i = 0; i <= KV_MAX_GRADE; ++i) {
+        m_dueWords[i] = wc.grades[i];
+    }
+    m_totalDueWords = wc.totalWords;
+
+    update();
 }
 
 
@@ -66,9 +77,13 @@ void BarWidget::paintEvent(QPaintEvent *)
     gradeBarWidth[8] = 0;
     int gradeBarOffset[9];
     gradeBarOffset[8] = 0;
-    if (percentageCompleted < 100) {
+
+    //qDebug() << "percentage completed: " << m_percentageCompleted;
+    //qDebug() << "Total due words: " << m_totalDueWords;
+
+    if (m_percentageCompleted < 100) {
         for(int j = 7; j >= 0; j--) {
-            gradeBarWidth[j] = (float)(dueWords[j]) / (float)(totalDueWords) * legendWidth;
+            gradeBarWidth[j] = (float)(m_dueWords[j]) / (float)(m_totalDueWords) * legendWidth;
             gradeBarOffset[j] = gradeBarOffset[j+1] + gradeBarWidth[j+1];
         }
     }
@@ -80,7 +95,7 @@ void BarWidget::paintEvent(QPaintEvent *)
         gradeBarWidth[7] = legendWidth;
         gradeBarOffset[7] = 0;
     }
-    if (percentageCompleted < 100 && totalDueWords == 0) {
+    if (m_percentageCompleted < 100 && m_totalDueWords == 0) {
         for(int j = 6; j >= 0; j--) {
             gradeBarWidth[j] = 0;
             gradeBarOffset[j] = legendWidth;
@@ -102,7 +117,7 @@ void BarWidget::paintEvent(QPaintEvent *)
         barElementPath.addRect(barElement);
         QPainterPath barElementIntersectedPath = roundedPath.intersected(barElementPath);
         QColor color;
-        if (totalDueWords == 0 && percentageCompleted < 100) {
+        if (m_totalDueWords == 0 && m_percentageCompleted < 100) {
             color = QColor(0, 0, 0, 128);
         }
         else {
@@ -111,13 +126,13 @@ void BarWidget::paintEvent(QPaintEvent *)
         painter.setBrush(QBrush(color));
         painter.drawPath(barElementIntersectedPath);
     }
+
     QPen pen(QColor(255,255,255));
+    //QPen pen(QColor(0, 0, 0));
     painter.setPen(pen);
-    if (percentageCompleted < 100) {
+    if (m_percentageCompleted < 100) {
         painter.drawText(0, 0, legendWidth, 20, Qt::AlignCenter,
-			 false  // Disabled until we get the number of words due working
-			 ? i18np("%1 word due", "%1 words due", totalDueWords)
-			 : "");
+			 i18np("%1 word due", "%1 words due", m_totalDueWords));
     }
     else {
         painter.drawText(0, 0, legendWidth, 20, Qt::AlignCenter, i18n("Fully learned"));
