@@ -25,13 +25,17 @@
 #include <QGraphicsDropShadowEffect>
 #include <QStandardItemModel>
 #include <QTimer>
-#include <QTime>
+#include <QAction>
 #include <QMessageBox>
 #include <QDebug>
 
 #include <QtGui>
 #include <Qt>
 
+//#include <KMimeType>
+#include <KActionCollection>
+
+#include "collection.h"
 #include "collectionwidget.h"
 #include "barwidget.h"
 #include "gradereferencewidget.h"
@@ -64,80 +68,90 @@ Dashboard::Dashboard(ParleyMainWindow *parent)
     m_widget->setKeepAspectRatio(Qt::IgnoreAspectRatio);
     m_widget->setFadingEnabled(false);
 
-    ui = new Ui::Dashboard();
-    ui->setupUi(m_widget);
+    m_ui = new Ui::Dashboard();
+    m_ui->setupUi(m_widget);
     setCentralWidget(m_widget);
-    practiceSignalMapper = new QSignalMapper(this);
-    removeSignalMapper = new QSignalMapper(this);
+    m_practiceSignalMapper = new QSignalMapper(this);
+    m_removeSignalMapper = new QSignalMapper(this);
 
+    // Need 8 colors for confidence 0..7.
+    // FIXME: Find a better color than gray for confidence 1.
+    // FIXME: Add a color for pregrades.
     gradeColor[0] = QColor(25,38,41);
-    gradeColor[1] = QColor(25,38,41,64);// Need 8 colors, so find a suitable color for this grade, currently gray.
+    gradeColor[1] = QColor(25,38,41,64);
     gradeColor[2] = QColor(237,21,21);
     gradeColor[3] = QColor(246,116,0);
     gradeColor[4] = QColor(201,206,59);
     gradeColor[5] = QColor(28,220,154);
     gradeColor[6] = QColor(17,209,22);
     gradeColor[7] = QColor(61,174,253);
-    gradeColor[8] = QColor(255,221,217);//These two are placeholders for the wordcloud background color.
-    gradeColor[9] = QColor(238,232,213);//
+
+    // These two are placeholders for the wordcloud background color.
+    gradeColor[8] = QColor(255,221,217);
+    gradeColor[9] = QColor(238,232,213);
 
     QTime time = QTime::currentTime();
     qsrand((uint)time.msec());
 
-    QFont font = ui->recentLabel->font();
+    QFont font = m_ui->recentLabel->font();
     font.setBold(true);
-    ui->recentLabel->setFont(font);
-    font = ui->completedLabel->font();
+    m_ui->recentLabel->setFont(font);
+    font = m_ui->completedLabel->font();
     font.setBold(true);
-    ui->completedLabel->setFont(font);
+    m_ui->completedLabel->setFont(font);
+
+    m_ui->newButton->setIcon(QIcon::fromTheme("document-new"));
+    m_ui->openButton->setIcon(QIcon::fromTheme("document-open"));
+    m_ui->ghnsButton->setIcon(QIcon::fromTheme("get-hot-new-stuff"));
 
-    ui->newButton->setIcon(QIcon::fromTheme("document-new"));
-    ui->openButton->setIcon(QIcon::fromTheme("document-open"));
-    ui->ghnsButton->setIcon(QIcon::fromTheme("get-hot-new-stuff"));
     GradeReferenceWidget *gradeReferenceWidget = new GradeReferenceWidget();
     gradeReferenceWidget->setMinimumSize(m_widget->width(), 50);
-    ui->gridLayout->addWidget(gradeReferenceWidget, 2, 0, 1, ROWSIZE, Qt::AlignCenter);
+    m_ui->gridLayout->addWidget(gradeReferenceWidget, 2, 0, 1, ROWSIZE, Qt::AlignCenter);
 
     m_subGridLayout = new QGridLayout();
     m_subGridLayout->setHorizontalSpacing(50);
     m_subGridLayout->setVerticalSpacing(30);
-    ui->gridLayout->addLayout(m_subGridLayout, 5, 0, 1, 4);
+    m_ui->gridLayout->addLayout(m_subGridLayout, 5, 0, 1, 4);
 
     m_completedGridLayout = new QGridLayout();
     m_completedGridLayout->setHorizontalSpacing(50);
     m_completedGridLayout->setVerticalSpacing(30);
-    ui->gridLayout->addLayout(m_completedGridLayout, 9, 0, 1, 4);
+    m_ui->gridLayout->addLayout(m_completedGridLayout, 9, 0, 1, 4);
 
     populateMap();
     populateGrid();
 
     // Signals from the main buttons.
     ParleyDocument* doc = m_mainWindow->parleyDocument();
-    connect(ui->newButton,  SIGNAL(clicked()), m_mainWindow, SLOT(slotFileNew()));
-    connect(ui->openButton, SIGNAL(clicked()), doc, SLOT(slotFileOpen()));
-    connect(ui->ghnsButton, SIGNAL(clicked()), doc, SLOT(slotGHNS()));
+    connect(m_ui->newButton,  SIGNAL(clicked()), m_mainWindow, SLOT(slotFileNew()));
+    connect(m_ui->openButton, SIGNAL(clicked()), doc, SLOT(slotFileOpen()));
+    connect(m_ui->ghnsButton, SIGNAL(clicked()), doc, SLOT(slotGHNS()));
 
     // Signals FROM the signal mappers.  The ones TO the signal mappers are
     // handled below.
-    connect(practiceSignalMapper, SIGNAL(mapped(const QString &)),
-       this,                 SLOT(slotPracticeButtonClicked(const QString &)));
-    connect(removeSignalMapper,   SIGNAL(mapped(const QString &)),
-       this,                 SLOT(slotRemoveButtonClicked(const QString &)));
+    connect(m_practiceSignalMapper, SIGNAL(mapped(const QString &)),
+	    this,                   SLOT(slotPracticeButtonClicked(const QString &)));
+    connect(m_removeSignalMapper,   SIGNAL(mapped(const QString &)),
+	    this,                   SLOT(slotRemoveButtonClicked(const QString &)));
 
     KConfigGroup cfg(KSharedConfig::openConfig("parleyrc"), objectName());
     applyMainWindowSettings(cfg);
 
     m_themedBackgroundRenderer = new Practice::ThemedBackgroundRenderer(this, "startpagethemecache.bin");
 
+    // Set theme and prepare for future theme changes.
     connect(Prefs::self(), SIGNAL(configChanged()), this, SLOT(setTheme()));
     setTheme();
 
-    connect(m_themedBackgroundRenderer, SIGNAL(backgroundChanged(QPixmap)), this, SLOT(backgroundChanged(QPixmap)));
+    connect(m_themedBackgroundRenderer, SIGNAL(backgroundChanged(QPixmap)),
+	    this,                       SLOT(backgroundChanged(QPixmap)));
     connect(m_widget, SIGNAL(sizeChanged()), this, SLOT(updateBackground()));
 
-    /*statisticsWidget = new StatisticsMainWindow(m_mainWindow->parleyDocument()->document(), m_mainWindow);
-    for (int i = 0; i < m_count; i++)
-        statisticsHandler(urlArray[i]); */ //Used to get the statistics for each Collection. TODO find a better way.
+    QAction *updateAction = new QAction(this);
+    updateAction->connect(updateAction, SIGNAL(triggered(bool)), this, SLOT(updateWidgets()));
+    actionCollection()->addAction("update_dashboard", updateAction);
+    //actionCollection()->setDefaultShortcut(updateAction, QKeySequence(Qt::Key_F5));
+    updateAction->setShortcut(QKeySequence(Qt::Key_F5));
 }
 
 Dashboard::~Dashboard()
@@ -201,7 +215,7 @@ void Dashboard::populateMap()
     for (int i = recentFilesGroup.keyList().count() / 2; i > 0 ; i--) {
         QString urlString = recentFilesGroup.readPathEntry("File" + QString::number(i), QString());
         QString nameString = recentFilesGroup.readEntry("Name" + QString::number(i), QString());
-        recentFilesMap.insert(urlString,nameString);
+        m_recentFilesMap.insert(urlString, nameString);
     }
 }
 
@@ -209,21 +223,23 @@ void Dashboard::populateGrid()
 {
     int j = 0, k = 0, jc = 0, kc = 0;
 
-    QMapIterator<QString, QString> it(recentFilesMap);
+    QMapIterator<QString, QString> it(m_recentFilesMap);
     while (it.hasNext()) {
         it.next();
-        QString urlString  = it.key();
-        QString nameString = it.value();
+        QString urlString   = it.key();
+        QString titleString = it.value();
 
-   // Automatically initialized.
-   // FIXME: Will be initialized by the KEduVocDocument later.
-   DueWords due;
+	QUrl  url(QUrl::fromLocalFile(urlString));
+	Collection *collection = new Collection(&url, this);
+	collection->close(); // We just want to look at it, not own it, so release the lock.
 
-        QUrl  url( QUrl::fromLocalFile(urlString) );
-        urlArray[k] = url;
+	// Automatically initialized.
+	DueWords due;
+
+        m_urlArray[k] = url;
         if (due.percentageCompleted != 100) {
             if (j % ROWSIZE == 0) {
-                m_subGridLayout->addItem(new QSpacerItem(50,1), j / ROWSIZE, 0);
+                m_subGridLayout->addItem(new QSpacerItem(50, 1), j / ROWSIZE, 0);
                 j++;
             }
         }
@@ -234,7 +250,10 @@ void Dashboard::populateGrid()
             }
         }
 
-        QWidget* backWidget = new CollectionWidget(nameString, &due);
+	//QWidget* backWidget = new CollectionWidget(collection, &due, this);
+	CollectionWidget* backWidget = new CollectionWidget(collection, &due, this);
+	m_collectionWidgets.append(backWidget);
+
         if (due.percentageCompleted != 100) {
                 backWidget->setFixedSize(COLLWIDTH, COLLHEIGHT1);
                 m_subGridLayout->addWidget(backWidget, j / ROWSIZE, j % ROWSIZE);
@@ -244,10 +263,10 @@ void Dashboard::populateGrid()
                 m_completedGridLayout->addWidget(backWidget, jc / ROWSIZE, jc % ROWSIZE);
         }
 
-        practiceSignalMapper->setMapping(backWidget, urlString);
-        connect(backWidget, SIGNAL(practiceButtonClicked()), practiceSignalMapper, SLOT(map()));
-        removeSignalMapper->setMapping(backWidget, urlString);
-        connect(backWidget, SIGNAL(removeButtonClicked()), removeSignalMapper, SLOT(map()));
+        m_practiceSignalMapper->setMapping(backWidget, urlString);
+        connect(backWidget, SIGNAL(practiceButtonClicked()), m_practiceSignalMapper, SLOT(map()));
+        m_removeSignalMapper->setMapping(backWidget, urlString);
+        connect(backWidget, SIGNAL(removeButtonClicked()), m_removeSignalMapper, SLOT(map()));
 
         if (due.percentageCompleted != 100) {
             j++;
@@ -268,14 +287,14 @@ void Dashboard::populateGrid()
     m_subGridLayout->addItem(new QSpacerItem(50,1,QSizePolicy::Expanding, QSizePolicy::Fixed),
               m_subGridLayout->rowCount() - 1, m_subGridLayout->columnCount());
     if (k - kc) {
-        ui->recentLabel->setText(i18n("Active Collections"));
+        m_ui->recentLabel->setText(i18n("Active Collections"));
     } else {
-        ui->recentLabel->clear();
+        m_ui->recentLabel->clear();
     }
     if (kc) {
-        ui->completedLabel->setText(i18n("Completed Collections"));
+        m_ui->completedLabel->setText(i18n("Completed Collections"));
     } else {
-        ui->completedLabel->clear();
+        m_ui->completedLabel->clear();
     }
 }
 
@@ -325,7 +344,7 @@ void Dashboard::slotRemoveButtonClicked(const QString& urlString)
               i18n("Are you sure you want to remove this collection?"),
               QMessageBox::Yes | QMessageBox::No);
     if (reply == QMessageBox::Yes) {
-        recentFilesMap.remove(urlString);
+        m_recentFilesMap.remove(urlString);
         m_mainWindow->removeRecentFile(QUrl::fromLocalFile(urlString ));
         clearGrid();
         populateGrid();
@@ -358,6 +377,12 @@ void Dashboard::setTheme()
     m_widget->setContentsMargins(m_themedBackgroundRenderer->contentMargins());
 }
 
+void Dashboard::updateWidgets()
+{
+    foreach (CollectionWidget *cw, m_collectionWidgets) {
+	cw->updateDue();
+    }
+}
 void Dashboard::updateFontColors()
 {
     QPalette p(QApplication::palette());
@@ -372,10 +397,10 @@ void Dashboard::updateBackground()
 {
     m_themedBackgroundRenderer->clearRects();
     m_themedBackgroundRenderer->addRect("startbackground", QRect(QPoint(), m_widget->size()));
-    QRect headerRect = ui->headingLabel->frameGeometry();
-    headerRect.setBottom(ui->recentFiles->frameGeometry().top() - 1);
+    QRect headerRect = m_ui->headingLabel->frameGeometry();
+    headerRect.setBottom(m_ui->recentFiles->frameGeometry().top() - 1);
     m_themedBackgroundRenderer->addRect("startheader", headerRect);
-    m_themedBackgroundRenderer->addRect("recentfiles", ui->recentFiles->frameGeometry());
+    m_themedBackgroundRenderer->addRect("recentfiles", m_ui->recentFiles->frameGeometry());
     QPixmap pixmap = m_themedBackgroundRenderer->getScaledBackground();
     if (!pixmap.isNull()) {
         m_widget->setPixmap(pixmap);
