@@ -23,7 +23,6 @@
 StatisticsModel::StatisticsModel(QObject * parent)
     : ContainerModel(KEduVocContainer::Lesson, parent)
 {
-    setSupportedDragActions(0);
 }
 
 QVariant StatisticsModel::headerData(int section, Qt::Orientation orientation, int role) const
@@ -90,6 +89,11 @@ int StatisticsModel::columnCount(const QModelIndex & parent) const
     return m_doc->identifierCount() + FirstDataColumn;
 }
 
+Qt::DropActions StatisticsModel::supportedDragActions() const
+{
+    return 0;
+}
+
 KEduVocContainer * StatisticsModel::rootContainer() const
 {
     if (!m_doc) {
@@ -97,5 +101,3 @@ KEduVocContainer * StatisticsModel::rootContainer() const
     }
     return m_doc->lesson();
 }
-
-#include "statisticsmodel.moc"
